{{#i18n}}Form title{{/i18n}}

{{&error}}

{{#fieldsets}}
  <fieldset>
    {{#title}}<legend>{{&title}}</legend>{{/title}}

      {{#widgets}}
        <div class="control-group {{#error}}error{{/error}}">
          <label class="control-label" for="{{id}} title="{{title}}">
            {{title}} {{#required}}*{{/required}}
          </label>
          <div class="controls">
            {{&field}}

            {{#error}}
              <span class="help-inline">{{error}}</span>
            {{/error}}
            {{#description}}
              <p class="help-block">{{&description}}</p>
            {{/description}}
          </div>
        </div>
      {{/widgets}}
  </fieldset>
{{/fieldsets}}
